@@ -1,3 +1,4 @@
+use colored::Colorize;
 use libium::config;
 
 pub fn list(config: &config::structs::Config) {
@@ -6,14 +7,14 @@ pub fn list(config: &config::structs::Config) {
             "{}{}
         \r  Output directory:   {}
         \r  Minecraft Version:  {}
-        \r  Mod Loader:         {:?}
+        \r  Mod Loader:         {}
         \r  Mods:               {}\n",
-            profile.name,
+            profile.name.bold(),
             if i == config.active_profile { " *" } else { "" },
-            profile.output_dir.display(),
-            profile.game_version,
-            profile.mod_loader,
-            profile.mods.len(),
+            profile.output_dir.display().to_string().blue().underline(),
+            profile.game_version.green(),
+            format!("{:?}", profile.mod_loader).purple(),
+            profile.mods.len().to_string().yellow(),
         );
     }
 }
