@@ -64,7 +64,7 @@ pub async fn upgrade(
             match result {
                 Ok((downloadable, backwards_compat)) => {
                     progress_bar.println(format!(
-                        "{} {:45} {}",
+                        "{} {:43} {}",
                         if backwards_compat {
                             backwards_compat_msg.store(true, Ordering::Relaxed);
                             YELLOW_TICK.clone()
@@ -72,7 +72,7 @@ pub async fn upgrade(
                             TICK.clone()
                         },
                         mod_.name,
-                        format!("({})", downloadable.filename).dimmed()
+                        downloadable.filename.dimmed()
                     ));
                     {
                         let mut to_download = to_download.force_lock();
@@ -88,12 +88,12 @@ pub async fn upgrade(
                     }
                     progress_bar.println(format!(
                         "{}",
-                        format!("{} {:45} {}", CROSS, mod_.name, err).red()
+                        format!("{} {:43} {}", CROSS, mod_.name, err).red()
                     ));
                     error.store(true, Ordering::Relaxed);
                 },
             }
-            progress_bar.inc(1);
+            progress_bar.set_position(progress_bar.position() + 1);
             Ok(())
         }));
     }
@@ -181,7 +181,7 @@ pub async fn upgrade(
                     size.to_string(Base::Base10, Style::Smart),
                     downloadable.filename.dimmed(),
                 ));
-                progress_bar.inc(1);
+                progress_bar.set_position(progress_bar.position() + 1);
                 Ok::<(), Error>(())
             }));
         }
